=== modified file 'debian/control'
--- debian/control	2014-07-08 13:30:42 +0000
+++ debian/control	2014-07-22 02:01:38 +0000
@@ -8,9 +8,12 @@
                python-flake8,
                pkg-config,
                python3,
+               qml-module-qttest [i386 amd64 armhf],
                qt5-default,
                qtbase5-dev (>= 5.0),
                qtdeclarative5-dev (>= 5.0),
+               qtdeclarative5-dev-tools [i386 amd64 armhf],
+               qtdeclarative5-ubuntu-ui-toolkit-plugin [i386 amd64 armhf],
                qtpim5-dev,
 Standards-Version: 3.9.4
 Homepage: https://launchpad.net/messaging-app

=== modified file 'tests/CMakeLists.txt'
--- tests/CMakeLists.txt	2014-07-10 17:59:04 +0000
+++ tests/CMakeLists.txt	2014-07-22 02:01:38 +0000
@@ -1,3 +1,5 @@
+add_subdirectory(qml)
+
 set(AUTOPILOT_DIR autopilot/messaging_app)
 
 execute_process(COMMAND python3 -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())"

=== added directory 'tests/qml'
=== added file 'tests/qml/CMakeLists.txt'
--- tests/qml/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ tests/qml/CMakeLists.txt	2014-07-22 02:01:38 +0000
@@ -0,0 +1,31 @@
+find_program(QMLTESTRUNNER_BIN
+    NAMES qmltestrunner
+    PATHS /usr/lib/*/qt5/bin
+    NO_DEFAULT_PATH
+)
+
+find_program(XVFB_RUN_BIN
+    NAMES xvfb-run
+)
+
+macro(DECLARE_QML_TEST TST_NAME TST_QML_FILE)
+    add_test(NAME ${TST_NAME}
+        WORKING_DIRECTORY ${CMAKE_BINARY_DIR}
+        COMMAND ${XVFB_RUN_BIN} -a -s "-screen 0 1024x768x24" ${QMLTESTRUNNER_BIN} -import ${imports_BINARY_DIR} -input ${CMAKE_CURRENT_SOURCE_DIR}/${TST_QML_FILE}
+    )
+endmacro()
+
+if(QMLTESTRUNNER_BIN AND XVFB_RUN_BIN)
+    declare_qml_test("message_bubble" tst_MessageBubble.qml)
+else()
+    if (NOT QMLTESTRUNNER_BIN)
+        message(WARNING "Qml tests disabled: qmltestrunner not found")
+    else()
+        message(WARNING "Qml tests disabled: xvfb-run not found")
+    endif()
+endif()
+
+set(QML_TST_FILES
+    tst_MessageBubble.qml
+)
+add_custom_target(tst_QmlFiles ALL SOURCES ${QML_TST_FILES})

=== added file 'tests/qml/tst_MessageBubble.qml'
--- tests/qml/tst_MessageBubble.qml	1970-01-01 00:00:00 +0000
+++ tests/qml/tst_MessageBubble.qml	2014-07-22 02:01:38 +0000
@@ -0,0 +1,101 @@
+/*
+ * Copyright 2014 Canonical Ltd.
+ *
+ * This file is part of messaging-app.
+ *
+ * messaging-app is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 3.
+ *
+ * messaging-app is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
+import QtQuick 2.2
+import QtTest 1.0
+import Ubuntu.Test 0.1
+
+import '../../src/qml/'
+
+Item {
+    id: root
+
+    width: units.gu(40)
+    height: units.gu(40)
+
+    MessageBubble {
+        id: incomingMessageBubble
+        objectName: 'incomingMessageBubble'
+
+        height: parent.height / 3
+
+        incoming: true
+    }
+
+    MessageBubble {
+        id: outgoingMessageBubble
+        objectName: 'outgoingMessageBubble'
+
+        anchors.top: incomingMessageBubble.bottom
+        height: parent.height / 3
+
+        incoming: false
+    }
+
+    MessageBubble {
+        id: changeIncomingMessageBubble
+        objectName: 'changeIncomingMessageBubble'
+
+        anchors.top: outgoingMessageBubble.bottom
+        height: parent.height / 3
+
+        incoming: true
+    }
+
+    UbuntuTestCase {
+        id: messageBubbleTestCase
+        name: 'messageBubbleTestCase'
+
+        when: windowShown
+
+        function init() {
+            waitForRendering(incomingMessageBubble);
+            waitForRendering(outgoingMessageBubble);
+            waitForRendering(changeIncomingMessageBubble);
+        }
+
+        function cleanup() {
+            changeIncomingMessageBubble.incoming = true;
+        }
+
+        function test_incoming_message_bubble_must_use_incoming_source() {
+            var incomingMessageBubble = findChild(
+                root, 'incomingMessageBubble');
+            compare(
+                incomingMessageBubble.source,
+                'assets/conversation_incoming.sci');
+        }
+
+        function test_outgoing_message_bubble_must_use_outgoing_source() {
+            var outgoingMessageBubble = findChild(
+                root, 'outgoingMessageBubble');
+            compare(
+                outgoingMessageBubble.source,
+                'assets/conversation_outgoing.sci');
+        }
+
+        function test_change_incoming_must_update_source() {
+            var changeIncomingMessageBubble = findChild(
+                root, 'changeIncomingMessageBubble');
+            changeIncomingMessageBubble.incoming = false;
+            compare(
+                changeIncomingMessageBubble.source,
+                'assets/conversation_outgoing.sci');
+        }
+    }
+}

